@@ -29,6 +29,7 @@ class PaymentMethod(Resource):
         options = [
             "fail_on_duplicate_payment_method",
             "make_default",
+            "us_bank_account_verification_method",
             "verification_merchant_account_id",
             "verify_card",
             "verification_amount",
@@ -45,6 +46,7 @@ class PaymentMethod(Resource):
                     "custom_field",
                     "description",
                     "amount",
+                    { "shipping": Address.create_signature() }
                 ],
             },
         ]
@@ -61,6 +63,8 @@ class PaymentMethod(Resource):
             "expiration_year",
             "number",
             "payment_method_nonce",
+            "paypal_refresh_token",
+            "paypal_vault_without_upgrade",
             "token",
             {
                 "billing_address": Address.create_signature()
@@ -90,6 +94,7 @@ class PaymentMethod(Resource):
             {
                 "options": [
                     "make_default",
+                    "us_bank_account_verification_method",
                     "verify_card",
                     "verification_amount",
                     "verification_merchant_account_id",
